==> seahorse-0.0.1b7.tar.gz: seahorse-0.0.1b7/README.md <==
<p align="center"><img width="70%" src="./docs/assets/logo_seahorse.png" /></p>

[![PyPI - Version](https://img.shields.io/pypi/v/seahorse.svg)](https://pypi.org/project/seahorse)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/seahorse.svg)](https://pypi.org/project/seahorse)
![License](https://img.shields.io/github/license/corail-research/seahorse)
![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/corail-research/seahorse/python-testing.yml)
![GitHub stars](https://img.shields.io/github/stars/corail-research/seahorse)
![GitHub contributors](https://img.shields.io/github/contributors/corail-research/seahorse)


# A handy package for kickstarting AI contests

We proudly provide a Python framework that makes the building of an environment for adversarial agents easy ! 

A lot of fun functionalities are provided an easily usable out of the box ! 

 - Implementing a new game setup from scratch ? **Painless !**
 - Playing against remote agents ? **Easy !** 
 - Generating and collecting data about played games ? **Worriless !**
 - Organizing a contest for a large range of agents ? **Quick and reliable !**

## Installation
The package is publicly available on PyPI.

We strongly encourage the use of a virtual environment:

```
    $ python3 -m venv venv

    $ source venv/bin/[activate|Activate.ps1]

    (venv)$ pip install seahorse

```

## Documentation 
Our full documentation and a series of tutorials are available on <a href="https://corail-research.github.io/seahorse/" target="blank">corail-research.io</a>.

## Main contributors
We are an enthusiastic team of M.Sc candidates led by Pr. Quentin Cappart at Polytechnique Montréal. The package was originally developed in the context of a introductory course to artificial intelligence given to undergrad computer and software engineering students.
Checkout our [lab's page](https://corail-research.github.io/team/) for more information.

## License

`seahorse` is distributed under the termes of the <a href="https://opensource.org/license/bsd-3-clause/" target="blank_">3-Clause BSD License</a>.

<div class="horizontal-container" style="display:inline-block; width:100%"> <p><img align="left" alt="Image title" src="./docs/assets/corail-logo.png" width="400"></p> <p><img align="left" alt="Image title" src="./docs/assets/logo_poly.png" width="160"></p>  </div>

==> seahorse-1.1.4.tar.gz: seahorse-1.1.4/README.md <==
<img width="70%" src="https://raw.githubusercontent.com/corail-research/seahorse/main/assets/logo_seahorse.png" />

[![PyPI - Version](https://img.shields.io/pypi/v/seahorse.svg)](https://pypi.org/project/seahorse)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/seahorse.svg)](https://pypi.org/project/seahorse)
![License](https://img.shields.io/github/license/corail-research/seahorse)
![GitHub Workflow Status (with event)](https://img.shields.io/github/actions/workflow/status/corail-research/seahorse/python-testing.yml)
![GitHub stars](https://img.shields.io/github/stars/corail-research/seahorse)
![GitHub contributors](https://img.shields.io/github/contributors/corail-research/seahorse)


# A handy package for kickstarting AI contests

We proudly provide a Python framework that makes the building of an environment for adversarial agents easy ! 

A lot of fun functionalities are provided an easily usable out of the box ! 

 - Implementing a new game setup from scratch ? **Painless !**
 - Playing against remote agents ? **Easy !** 
 - Generating and collecting data about played games ? **Worriless !**
 - Organizing a contest for a large range of agents ? **Quick and reliable !**

## Installation
The package is publicly available on PyPI.

We strongly encourage the use of a virtual environment:

```
    $ python3 -m venv venv

    $ source venv/bin/[activate|Activate.ps1]

    (venv)$ pip install seahorse

```

## Documentation 
Our full documentation and a series of tutorials are available on <a href="https://corail-research.github.io/seahorse/" target="blank">corail-research.github.io</a>.

## Main contributors
We are an enthusiastic team of M.Sc candidates led by Pr. Quentin Cappart at Polytechnique Montréal. The package was originally developed in the context of a introductory course to artificial intelligence given to undergrad computer and software engineering students.
Checkout our [lab's page](https://corail-research.github.io/team/) for more information.

## License

`seahorse` is distributed under the termes of the <a href="https://opensource.org/license/bsd-3-clause/" target="blank_">3-Clause BSD License</a>.

<div class="horizontal-container" style="display:inline-block; width:100%"> <p><img src="https://raw.githubusercontent.com/corail-research/seahorse/main/docs/assets/corail-logo.png" width=400/><img src="https://raw.githubusercontent.com/corail-research/seahorse/main/docs/assets/logo_poly.png" width=150/></p>
</p>  </div>
